is_pure_module

Function is_pure_module 

pub fn is_pure_module(kind: &str) -> bool
kind is one of the known pure module aliases — used by the policy walk to skip pure builtins that programs reference via imports.